.. Copyright (C) 2025 @verzierf <francois.verzier@univ-grenoble-alpes.fr>

.. SPDX-License-Identifier: LGPL-3.0-or-later

.. _api_reference:

=============
API reference
=============

.. autosummary::
   :toctree: _autosummary
   :recursive:

   mater_data_providing